@@ -1,16 +1,17 @@
 /*
- * $Id: PdfName.java 6060 2013-11-06 14:07:28Z pavel-alay $
+ * $Id: PdfName.java 6229 2014-02-11 11:27:04Z michaeldemey $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -1118,6 +1119,11 @@ public class
     public static final PdfName LASTPAGE = new PdfName("LastPage");
     /** A name */
     public static final PdfName LAUNCH = new PdfName("Launch");
+    /**
+     * A name
+     * @since 5.5.0
+     */
+    public static final PdfName LAYOUT = new PdfName("Layout");
     /**
      * A name
      * @since 2.1.6
@@ -1500,6 +1506,11 @@ public class
     public static final PdfName PI = new PdfName("PI");
     /** A name */
     public static final PdfName PICKTRAYBYPDFSIZE = new PdfName("PickTrayByPDFSize");
+    /**
+     * A name
+     * @since 5.5.0
+     */
+    public static final PdfName PIECEINFO = new PdfName("PieceInfo");
     /**
      * A name.
      * @since 2.1.6
