@@ -12,19 +12,13 @@ import org.xml.sax.SAXException;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
-import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
-import java.io.IOException;
+import java.io.*;
 
 public class TaggedPdfTest {
     private Document document;
     private PdfWriter writer;
     private Paragraph h1;
 
-    public static final String NO_PARENT_TREE = "the.document.does.not.contain.parenttree";
-    public static final String NO_STRUCT_TREE_ROOT = "no.StructTreeRoot.found";
-
     private static final String text = new String("Lorem ipsum dolor sit amet," +
             "consectetur adipiscing elit." +
             "Pellentesque a lectus sit amet lectus accumsan aliquam." +
@@ -73,11 +67,10 @@ public class TaggedPdfTest {
 
         //Required for PDF/UA
         writer.setViewerPreferences(PdfWriter.DisplayDocTitle);
-        writer.createXmpMetadata();
         document.addLanguage("en-US");
         document.addTitle("Some title");
+        writer.createXmpMetadata();
         Chunk c = new Chunk("Document Header", new Font(Font.FontFamily.HELVETICA,14,Font.BOLD,BaseColor.BLUE));
-        c.setRole(null);
         h1 = new Paragraph(c);
         h1.setRole(PdfName.H1);
     }
@@ -149,8 +142,6 @@ public class TaggedPdfTest {
         columnText.setSimpleColumn(300, 36, 500, 800);
         columnText.go();
         document.close();
-        int[] nums = new int[]{77} ;
-        compareNums("1", nums);
         compareResults("1");
     }
 
@@ -168,8 +159,6 @@ public class TaggedPdfTest {
         columnText.setSimpleColumn(36,36,400,800);
         columnText.go();
         document.close();
-//        int[] nums = new int[]{237, 47} ;
-//        compareNums("2", nums);
         compareResults("2");
     }
 
@@ -180,8 +169,6 @@ public class TaggedPdfTest {
         document.add(h1);
         document.add(paragraph);
         document.close();
-        int[] nums = new int[]{43, 6};
-        compareNums("3", nums);
         compareResults("3");
     }
 
@@ -218,8 +205,6 @@ public class TaggedPdfTest {
         document.add(h1);
         document.add(p);
         document.close();
-        int[] nums = new int[]{7};
-        compareNums("4", nums);
         compareResults("4");
     }
 
@@ -237,13 +222,11 @@ public class TaggedPdfTest {
             listItem = new ListItem(c);
             list.add(listItem);
             listItem = new ListItem(new Chunk("jumped over a lazy"));
-            listItem.getListLabel().setTagLabelContent(false);
             list.add(listItem);
             i = Image.getInstance("./src/test/resources/com/itextpdf/text/pdf/TaggedPdfTest/dog.bmp");
             c = new Chunk(i, 0, 0);
             c.setAccessibleAttribute(PdfName.ALT, new PdfString("Dog image"));
             listItem = new ListItem(c);
-            listItem.getListLabel().setTagLabelContent(false);
             list.add(listItem);
         } catch (Exception e) {
 
@@ -252,8 +235,6 @@ public class TaggedPdfTest {
         document.add(list);
         document.close();
 
-        int[] nums = new int[]{22};
-        compareNums("5", nums);
         compareResults("5");
     }
 
@@ -288,8 +269,6 @@ public class TaggedPdfTest {
         columnText.addElement(list);
         columnText.go();
         document.close();
-        int[] nums = new int[]{24};
-        compareNums("6", nums);
         compareResults("6");
     }
 
@@ -322,8 +301,6 @@ public class TaggedPdfTest {
         document.add(list);
         document.close();
 
-        int[] nums = new int[]{63, 14} ;
-        compareNums("7", nums);
         compareResults("7");
     }
 
@@ -364,8 +341,6 @@ public class TaggedPdfTest {
         columnText.go();
         document.close();
 
-        int[] nums = new int[]{64, 35} ;
-        compareNums("8", nums);
         compareResults("8");
     }
 
@@ -392,8 +367,6 @@ public class TaggedPdfTest {
         document.add(table);
         document.add(new Paragraph("Extra paragraph at the end of the document. Please make sure that this is really last portion of page content."));
         document.close();
-        int[] nums = new int[]{16, 70, 62} ;
-        compareNums("9", nums);
         compareResults("9");
     }
 
@@ -434,8 +407,6 @@ public class TaggedPdfTest {
         document.add(table);
         document.close();
 
-        int[] nums = new int[]{16, 87, 128, 74, 74, 74, 26} ;
-        compareNums("10", nums);
         compareResults("10");
     }
 
@@ -564,8 +535,6 @@ public class TaggedPdfTest {
 
         document.close();
 
-        int[] nums = new int[]{114, 63} ;
-        compareNums("11", nums);
         compareResults("11");
     }
 
@@ -599,8 +568,6 @@ public class TaggedPdfTest {
         document.add(table);
         document.close();
 
-        int[] nums = new int[]{237, 47} ;
-        compareNums("12", nums);
         compareResults("12");
     }
 
@@ -619,8 +586,6 @@ public class TaggedPdfTest {
         p.add(new Chunk(" for more details."));
         document.add(p);
         document.close();
-//        int[] nums = new int[]{5, 1} ;
-//        compareNums("13", nums);
         compareResults("13");
     }
 
@@ -634,10 +599,6 @@ public class TaggedPdfTest {
         columnText.addElement(paragraph);
         columnText.go();
         document.close();
-
-        int[] nums = new int[]{3} ;
-        compareNums("14", nums);
-
         PdfReader reader = new PdfReader("./target/com/itextpdf/test/pdf/TaggedPdfTest/out14.pdf");
         Assert.assertEquals(1, reader.getNumberOfPages());
     }
@@ -655,8 +616,6 @@ public class TaggedPdfTest {
 
         document.add(p);
         document.close();
-        int[] nums = new int[]{3} ;
-        compareNums("15", nums);
         compareResults("15");
     }
 
@@ -682,8 +641,6 @@ public class TaggedPdfTest {
 
 
         document.close();
-        int[] nums = new int[]{48, 7} ;
-        compareNums("16", nums);
         compareResults("16");
     }
 
@@ -730,8 +687,6 @@ public class TaggedPdfTest {
         }
         document.add(table);
         document.close();
-        int[] nums = new int[]{27} ;
-        compareNums("17", nums);
         compareResults("17");
     }
 
@@ -749,8 +704,6 @@ public class TaggedPdfTest {
         div.addElement(paragraph);
         document.add(div);
         document.close();
-        int[] nums = new int[]{32} ;
-        compareNums("18", nums);
         compareResults("18");
     }
 
@@ -912,8 +865,6 @@ public class TaggedPdfTest {
         document.add(h1);
         document.add(p);
         document.close();
-        int[] nums = new int[]{7};
-        compareNums("22", nums);
         compareResults("22");
     }
 
@@ -947,35 +898,62 @@ public class TaggedPdfTest {
         document.add(table);
         document.close();
 
-        int[] nums = new int[]{234, 44} ;
-        compareNums("23", nums);
         compareResults("23");
     }
 
-    private void compareNums(String name, int[] nums) throws IOException {
-        PdfReader reader = new PdfReader("./target/com/itextpdf/test/pdf/TaggedPdfTest/out"+ name +".pdf");
-        PdfDictionary structTreeRoot = verifyIsDictionary(reader.getCatalog().getDirectObject(PdfName.STRUCTTREEROOT), NO_STRUCT_TREE_ROOT);
-        verifyArraySize(structTreeRoot.get(PdfName.K), 1, "Invalid count of kids in StructTreeRoot");
-        PdfObject obj = PdfStructTreeController.getDirectObject(structTreeRoot.get(PdfName.PARENTTREE));
-        verifyIsDictionary(obj, NO_PARENT_TREE);
-        PdfArray array = ((PdfDictionary)obj).getAsArray(PdfName.NUMS);
-        verifyArraySize(array, nums.length*2, "nums");
-        for (int i = 0; i < nums.length; ++i)
-            verifyArraySize(PdfStructTreeController.getDirectObject(array.getPdfObject(i*2+1)), nums[i], "Nums of page "+(i+1));
-        reader.close();
-    }
+    @Test
+    public void createTaggedPdf24() throws DocumentException, IOException, ParserConfigurationException, SAXException {
+        Document document = new Document(PageSize.LETTER);
 
-    private PdfArray verifyArraySize(PdfObject obj, int size, String message) {
-        if (obj == null || !obj.isArray()) Assert.fail(message + " is not array");
-        if (((PdfArray)obj).size() != size)
-            Assert.fail(message + " has wrong size");
-        return (PdfArray)obj;
-    }
 
-    private PdfDictionary verifyIsDictionary(PdfObject obj, String message) {
-        if (obj == null || !obj.isDictionary())
-            Assert.fail(message);
-        return (PdfDictionary)obj;
+
+        ByteArrayOutputStream baos = new ByteArrayOutputStream();
+
+        PdfWriter writer = PdfWriter.getInstance(document, baos);
+
+        writer.setViewerPreferences(PdfWriter.DisplayDocTitle);
+
+//set more document properties
+
+        writer.setPdfVersion(PdfWriter.VERSION_1_7);
+        writer.setTagged(PdfWriter.markInlineElementsOnly);
+        PdfDictionary info = writer.getInfo();
+        info.put(PdfName.TITLE, new PdfString("Testing"));
+
+        writer.createXmpMetadata();
+
+
+// step 3
+
+        document.open();
+        document.addLanguage("en_US");
+        document.setAccessibleAttribute(PdfName.LANG, new PdfString("en_US"));
+
+// step 4
+
+        Paragraph p = new Paragraph("Paragraph testing testing");
+        p.setAccessibleAttribute(PdfName.ACTUALTEXT, new PdfString("Paragraph ALT Text"));
+        p.setAccessibleAttribute(PdfName.ALT, new PdfString("Paragraph ALT Text"));
+        document.add(p);
+
+
+        Chunk ck = new Chunk("Span testing testing", FontFactory.getFont("./src/test/resources/com/itextpdf/text/pdf/FreeMonoBold.ttf", BaseFont.WINANSI, BaseFont.EMBEDDED, 12));
+        ck.setAccessibleAttribute(PdfName.ACTUALTEXT, new PdfString("Span ALT Text"));
+        ck.setAccessibleAttribute(PdfName.ALT, new PdfString("Span ALT Text"));
+        p = new Paragraph(ck);
+        document.add(p);
+
+// step 5
+        document.close();
+
+        FileOutputStream fos = new FileOutputStream(new File("./target/com/itextpdf/test/pdf/TaggedPdfTest/out24.pdf"));
+
+        fos.write(baos.toByteArray());
+
+        fos.flush();
+
+        fos.close();
+        compareResults("24");
     }
 
     private boolean compareXmls(String xml1, String xml2) throws ParserConfigurationException, SAXException, IOException {
